<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use Illuminate\Validation\ValidationException;
use App\Http\Requests\Auth\LoginRequest;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\View\View;

class AuthenticatedSessionController extends Controller
{
    /**
     * Display the login view.
     */
    public function create(): View
    {
        return view('auth.login');
    }

    /**
     * Handle an incoming authentication request.
     */
    public function store(Request $request): RedirectResponse
{
    $request->validate([
        'email' => ['required', 'string', 'email'],
        'password' => ['required', 'string'],
    ]);

    if (! Auth::attempt($request->only('email', 'password'), $request->boolean('remember'))) {
        throw ValidationException::withMessages([//ini eror
            'email' => trans('auth.failed'),
        ]);
    }

    $request->session()->regenerate();

    $user = Auth::user();

    if (! $user->is_active) {
        Auth::logout();
        return redirect('/login')->withErrors(['email' => 'Akun belum diaktifkan oleh admin.']);
    }

    return match ($user->role) {
    'admin' => redirect('/admin/dashboard'),
    'guru' => redirect('/guru/dashboard'),
    'siswa' => redirect('/siswa/dashboard'),
    default => abort(403),
};

}


    /**
     * Destroy an authenticated session.
     */
    public function destroy(Request $request): RedirectResponse
    {
        Auth::guard('web')->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return redirect('/');
    }
}
