@extends('admin.layouts.app')

@section('title', 'Tambah Prodi Lanjutan')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Tambah Prodi Lanjutan</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('admin.prodi-lanjutan.index') }}">prodi</a></div>
    </div>
  </div>

  <div class="section-body">

    {{-- Notifikasi Sukses --}}
    @if (session('success'))
      <div class="alert alert-success alert-dismissible fade show" role="alert">
        <i class="fas fa-check-circle"></i> {{ session('success') }}
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
    @endif

    {{-- Notifikasi Error --}}
    @if ($errors->any())
      <div class="alert alert-danger alert-dismissible fade show" role="alert">
        <i class="fas fa-exclamation-triangle"></i> {{ $errors->first() }}
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
    @endif

    <div class="card">
      <div class="card-body">
        <form action="{{ route('admin.prodi-lanjutan.store') }}" method="POST">
          @csrf
          <div class="form-group mb-3">
            <label for="nama" class="form-label">Nama Prodi</label>
            <input type="text" name="nama" id="nama" class="form-control" required>
          </div>

          <div class="form-group mb-3">
            <label for="mapel_id" class="form-label">Pilih Mapel</label>
            <select name="mapel_id[]" id="mapel_id" class="form-control select2" multiple="multiple" required>
              @foreach ($mapels as $mapel)
                <option value="{{ $mapel->id }}">{{ $mapel->nama_mapel }}</option>
              @endforeach
            </select>
          </div>

          <button type="submit" class="btn btn-primary">
            <i class="fas fa-save"></i> Simpan
          </button>
          <a href="{{ route('admin.prodi-lanjutan.index') }}" class="btn btn-secondary">Kembali</a>
        </form>
      </div>
    </div>
  </div>
</section>
@endsection

@section('styles')
<!-- Select2 CSS -->
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />
<style>
  .select2-container--default .select2-selection--multiple {
    min-height: 44px;
    border: 1px solid #ced4da;
    border-radius: 4px;
    padding: 0.4rem;
  }
</style>
@endsection

@section('scripts')
<!-- jQuery (wajib sebelum Select2) -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

<!-- Select2 JS -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>

<script>
  $(document).ready(function () {
    $('#mapel_id').select2({
      placeholder: "Pilih Mapel",
      allowClear: true,
      width: '100%'
    });
  });
</script>
@endsection
