@extends('admin.layouts.app')

@section('title', 'Tambah Guru')

@section('content')

<section class="section">
  <div class="section-header">
    <h1>Tambah Data Guru</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('admin.guru.index') }}">Data guru</a></div>
      <div class="breadcrumb-item active">Tambah Guru</div>
    </div>
  </div>

  <div class="section-body">

    {{-- Notifikasi Sukses --}}
    @if(session('success'))
      <div class="alert alert-success alert-dismissible fade show" role="alert">
        {{ session('success') }}
        <button type="button" class="close" data-dismiss="alert" aria-label="Close"><span aria-hidden="true">&times;</span></button>
      </div>
    @endif

    {{-- Notifikasi Error --}}
    @if ($errors->any())
      <div class="alert alert-danger">
        <strong>Terjadi kesalahan:</strong>
        <ul class="mb-0 mt-1">
          @foreach ($errors->all() as $error)
              <li>{{ $error }}</li>
          @endforeach
        </ul>
      </div>
    @endif

    <div class="card" style="max-width: 700px;">
      <div class="card-header">
        <h4>Form Tambah Guru</h4>
      </div>
      <div class="card-body">
        <form action="{{ route('admin.guru.store') }}" method="POST">
          @csrf

          <div class="form-group">
            <label for="nip">NIP/NUPTK</label>
            <input type="text" name="nip" id="nip" class="form-control @error('nip') is-invalid @enderror" placeholder="ASDF-GHIJ-KLMN-OPQR" required value="{{ old('nip') }}">
            @error('nip')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="nama">Nama Lengkap</label>
            <input type="text" name="nama" id="nama" class="form-control @error('nama') is-invalid @enderror" required value="{{ old('nama') }}">
            @error('nama')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="email">Email</label>
            <input type="email" name="email" id="email" class="form-control @error('email') is-invalid @enderror" required value="{{ old('email') }}">
            @error('email')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="jenis_kelamin">Jenis Kelamin</label>
            <select name="jenis_kelamin" id="jenis_kelamin" class="form-control @error('jenis_kelamin') is-invalid @enderror" required>
              <option value="">-- Pilih Jenis Kelamin --</option>
              <option value="L" {{ old('jenis_kelamin') == 'L' ? 'selected' : '' }}>Laki-laki</option>
              <option value="P" {{ old('jenis_kelamin') == 'P' ? 'selected' : '' }}>Perempuan</option>
            </select>
            @error('jenis_kelamin')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="jabatan">Jabatan</label>
            <input type="text" name="jabatan" id="jabatan" class="form-control @error('jabatan') is-invalid @enderror" required value="{{ old('jabatan') }}">
            @error('jabatan')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="tahun_ajaran_id">Tahun Ajaran</label>
            <select name="tahun_ajaran_id" id="tahun_ajaran_id" class="form-control @error('tahun_ajaran_id') is-invalid @enderror" required>
              <option value="">-- Pilih Tahun Ajaran --</option>
              @foreach($tahunAjaranList as $tahunAjaran)
                <option value="{{ $tahunAjaran->id }}" {{ old('tahun_ajaran_id') == $tahunAjaran->id ? 'selected' : '' }}>
                  {{ $tahunAjaran->tahun }}{{ $tahunAjaran->semester }}
                </option>
              @endforeach
            </select>
            @error('tahun_ajaran_id')
                <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group mb-0">
            <button type="submit" class="btn btn-primary">Simpan</button>
            <a href="{{ route('admin.guru.index') }}" class="btn btn-secondary">Batal</a>
          </div>

        </form>
      </div>
    </div>
  </div>
</section>

@endsection
