@extends('admin.layouts.app')

@section('title', 'Tambah Guru Mengajar')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Tambah Guru Mengajar</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('admin.guru-mapel.index') }}">Data Guru Mengajar</a></div>
      <div class="breadcrumb-item active">Tambah Guru Mengajar</div>
    </div>
  </div>

  <div class="section-body">
    {{-- Notifikasi Sukses --}}
    @if(session('success'))
      <div class="alert alert-success alert-dismissible fade show" role="alert">
        {{ session('success') }}
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
    @endif

    {{-- Notifikasi Error --}}
    @if ($errors->any())
      <div class="alert alert-danger">
        <strong>Terjadi kesalahan:</strong>
        <ul class="mb-0 mt-1">
          @foreach ($errors->all() as $error)
            <li>{{ $error }}</li>
          @endforeach
        </ul>
      </div>
    @endif

    <div class="card" style="max-width:600px;">
      <div class="card-body">
        <form action="{{ route('admin.guru-mapel.store') }}" method="POST">
          @csrf

          <div class="form-group">
            <label>Kelas</label>
            <select name="kelas_id" class="form-control" required>
              <option value="">-- Pilih Kelas --</option>
              @foreach($kelas as $k)
                <option value="{{ $k->id }}" {{ old('kelas_id') == $k->id ? 'selected' : '' }}>
                  {{ $k->nama_kelas }}{{ $k->tingkat }}
                </option>
              @endforeach
            </select>
            @error('kelas_id') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <label>Mapel</label>
            <select name="mapel_id" class="form-control" required>
              <option value="">-- Pilih Mapel --</option>
              @foreach($mapel as $m)
                <option value="{{ $m->id }}" {{ old('mapel_id') == $m->id ? 'selected' : '' }}>
                  {{ $m->nama_mapel }}
                </option>
              @endforeach
            </select>
            @error('mapel_id') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <label>Guru</label>
            <select name="guru_id" class="form-control" required>
              <option value="">-- Pilih Guru --</option>
              @foreach($guru as $g)
                <option value="{{ $g->id }}" {{ old('guru_id') == $g->id ? 'selected' : '' }}>
                  {{ $g->nama }}
                </option>
              @endforeach
            </select>
            @error('guru_id') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <label>Hari</label>
            <select name="hari" class="form-control" required>
              <option value="">-- Pilih Hari --</option>
              @foreach(['Senin','Selasa','Rabu','Kamis','Jumat','Sabtu','Minggu'] as $hari)
                <option value="{{ $hari }}" {{ old('hari') == $hari ? 'selected' : '' }}>{{ $hari }}</option>
              @endforeach
            </select>
            @error('hari') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <label>Jam Mulai</label>
            <input type="time" name="jam_mulai" class="form-control" value="{{ old('jam_mulai') }}" required>
            @error('jam_mulai') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <label>Jam Selesai</label>
            <input type="time" name="jam_selesai" class="form-control" value="{{ old('jam_selesai') }}" required>
            @error('jam_selesai') <small class="text-danger">{{ $message }}</small> @enderror
          </div>

          <div class="form-group">
            <button class="btn btn-primary" type="submit">Simpan</button>
            <a href="{{ route('admin.guru-mapel.index') }}" class="btn btn-secondary">Batal</a>
          </div>
        </form>
      </div>
    </div>
  </div>
</section>
@endsection
