@extends('admin.layouts.app')

@section('title', 'Data Guru Mengajar')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Data Guru Mengajar</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item active">Data Guru Mengajar</div>
    </div>
    <div class="section-header-button">
      <a href="{{ route('admin.guru-mapel.create') }}" class="btn btn-primary">+ Tambah Data</a>
    </div>
  </div>

  {{-- Notifikasi --}}
  @if (session('success'))
    <div class="alert alert-success alert-dismissible fade show" role="alert">
      {{ session('success') }}
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  @if (session('error'))
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
      {{ session('error') }}
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Daftar Guru Mengajar</h4>
        <div class="card-header-form">
          <form method="GET" action="{{ route('admin.guru-mapel.index') }}">
            <div class="input-group">
              <input type="text" name="search" class="form-control" placeholder="Search" value="{{ request('search') }}">
              <div class="input-group-btn">
                <button class="btn btn-primary"><i class="fas fa-search"></i></button>
              </div>
            </div>
          </form>
        </div>
      </div>

      <div class="card-body p-0">
        <div class="table-responsive">
          <table class="table table-striped table-md">
            <thead>
              <tr>
                <th>#</th>
                <th>Kelas</th>
                <th>Mata Pelajaran</th>
                <th>Guru</th>
                <th>Hari</th>
                <th>Jam</th>
                <th>Aksi</th>
              </tr>
            </thead>
            <tbody>
              @forelse($data as $index => $item)
                <tr>
                  <td>{{ $loop->iteration + ($data->currentPage() - 1) * $data->perPage() }}</td>
                  <td>{{ $item->kelas->nama_kelas }}{{ $item->kelas->tingkat }}</td>
                  <td>{{ $item->mapel->nama_mapel }}</td>
                  <td>{{ $item->guru->nama }}</td>
                  <td>{{ $item->hari }}</td>
                  <td>{{ \Carbon\Carbon::parse($item->jam_mulai)->format('H:i') }} - {{ \Carbon\Carbon::parse($item->jam_selesai)->format('H:i') }}</td>
                  <td>
                    <a href="{{ route('admin.guru-mapel.edit', $item->id) }}" class="btn btn-warning btn-sm">
                      <i class="fas fa-edit"></i>
                    </a>
                    <form action="{{ route('admin.guru-mapel.destroy', $item->id) }}" method="POST" class="d-inline" onsubmit="return confirm('Yakin ingin menghapus data ini?')">
                      @csrf
                      @method('DELETE')
                      <button class="btn btn-danger btn-sm">
                        <i class="fas fa-trash"></i>
                      </button>
                    </form>
                  </td>
                </tr>
              @empty
                <tr>
                  <td colspan="7" class="text-center">Belum ada data guru mengajar.</td>
                </tr>
              @endforelse
            </tbody>
          </table>
        </div>
      </div>

      @if ($data->hasPages())
      <div class="card-footer text-center">
        {{ $data->links('vendor.pagination.bootstrap-4') }}
      </div>
      @endif

    </div>
  </div>
</section>
@endsection
