@extends('admin.layouts.app')

@section('title', 'Edit Kelas')

@section('content')

<section class="section">

  <div class="section-header">
    <h1>Edit Data Kelas</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('admin.kelas.index') }}">Data kelas</a></div>
    </div>
  </div>

  {{-- Notifikasi --}}
  @if (session('success'))
    <div class="alert alert-success alert-dismissible fade show" role="alert">
      {{ session('success') }}
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  @if ($errors->any())
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
      <strong>Terjadi kesalahan!</strong> Periksa kembali data yang Anda input.
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  <div class="section-body">
    <div class="card" style="max-width: 700px;">
      <div class="card-header">
        <h4>Form Edit Kelas</h4>
      </div>
      <div class="card-body">
        <form action="{{ route('admin.kelas.update', $kelas->id) }}" method="POST">
          @csrf
          @method('PUT')

          <div class="form-group">
            <label for="nama_kelas">Nama Kelas</label>
            <input type="text" name="nama_kelas" id="nama_kelas" class="form-control @error('nama_kelas') is-invalid @enderror" value="{{ old('nama_kelas', $kelas->nama_kelas) }}" required>
            @error('nama_kelas')
              <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="tingkat">Tingkat</label>
            <input type="text" name="tingkat" id="tingkat" class="form-control @error('tingkat') is-invalid @enderror" value="{{ old('tingkat', $kelas->tingkat) }}" required>
            @error('tingkat')
              <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group">
            <label for="jurusan">Jurusan</label>
            <input type="text" name="jurusan" id="jurusan" class="form-control @error('jurusan') is-invalid @enderror" value="{{ old('jurusan', $kelas->jurusan) }}" placeholder="(Opsional)">
            @error('jurusan')
              <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <!-- Dropdown Tahun Ajaran -->
          <div class="form-group">
            <label for="tahun_ajaran_id">Tahun Ajaran</label>
            <select name="tahun_ajaran_id" id="tahun_ajaran_id" class="form-control @error('tahun_ajaran_id') is-invalid @enderror" required>
              <option value="" disabled>-- Pilih Tahun Ajaran --</option>
              @foreach ($tahunAjarans as $tahun)
                <option value="{{ $tahun->id }}" 
                  {{ old('tahun_ajaran_id', $kelas->tahun_ajaran_id) == $tahun->id ? 'selected' : '' }}>
                  {{ $tahun->nama_tahun }}
                </option>
              @endforeach
            </select>
            @error('tahun_ajaran_id')
              <div class="invalid-feedback">{{ $message }}</div>
            @enderror
          </div>

          <div class="form-group mb-0">
            <button type="submit" class="btn btn-primary">Update</button>
            <a href="{{ route('admin.kelas.index') }}" class="btn btn-secondary">Batal</a>
          </div>

        </form>
      </div>
    </div>
  </div>
</section>

@endsection
