@extends('admin.layouts.app')

@section('title', 'Kelas Mapel')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Data Kelas Mapel</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item active">Kelas Mapel</div>
    </div>
    <div class="section-header-button">
      <a href="{{ route('admin.kelas_mapel.create') }}" class="btn btn-primary">
        <i class="fas fa-plus"></i> Tambah Data
      </a>
    </div>
  </div>

  {{-- Notifikasi --}}
  @if (session('success'))
    <div class="alert alert-success alert-dismissible fade show" role="alert">
      {{ session('success') }}
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  @if ($errors->any())
    <div class="alert alert-danger alert-dismissible fade show" role="alert">
      <strong>Terjadi kesalahan!</strong> {{ $errors->first() }}
      <button type="button" class="close" data-dismiss="alert" aria-label="Close">
        <span aria-hidden="true">&times;</span>
      </button>
    </div>
  @endif

  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Daftar Kelas, Mapel & Tahun Ajaran</h4>
      </div>

      <div class="card-body">
        {{-- Filter Tahun Ajaran --}}
        <form method="GET" class="mb-4">
          <div class="form-group row">
            <label class="col-sm-2 col-form-label">Filter Tahun Ajaran</label>
            <div class="col-sm-6">
              <select name="tahun_ajaran_id" class="form-control" onchange="this.form.submit()">
                @foreach ($tahunAjaranAll as $ta)
                  <option value="{{ $ta->id }}" {{ $selectedTahun == $ta->id ? 'selected' : '' }}>
                    {{ $ta->tahun }}{{ $ta->semester }}
                  </option>
                @endforeach
              </select>
            </div>
          </div>
        </form>

        <div class="table-responsive">
          <table class="table table-striped table-md">
            <thead>
              <tr>
                <th>#</th>
                <th>Kelas</th>
                <th>Tingkat</th>
                <th>Mapel</th>
                <th>Tahun Ajaran</th>
                <th>Aksi</th>
              </tr>
            </thead>
            <tbody>
              @forelse($data as $item)
                <tr>
                  <td>{{ $loop->iteration + ($data->currentPage() - 1) * $data->perPage() }}</td>
                  <td>{{ $item->kelas->nama_kelas ?? '-' }}</td>
                  <td>{{ $item->kelas->tingkat ?? '-' }}</td>
                  <td>{{ $item->mapel->nama_mapel ?? '-' }}</td>
                  <td>{{ $item->tahunAjaran->tahun ?? '-' }}</td>
                  <td class="d-flex">
                    <a href="{{ route('admin.kelas_mapel.edit', $item->id) }}" class="btn btn-warning btn-sm mr-2" title="Edit">
                      <i class="fas fa-edit"></i> Edit
                    </a>
                    <form action="{{ route('admin.kelas_mapel.destroy', $item->id) }}" method="POST" onsubmit="return confirm('Yakin ingin hapus?')">
                      @csrf
                      @method('DELETE')
                      <button class="btn btn-danger btn-sm" title="Hapus">
                        <i class="fas fa-trash-alt"></i> Hapus
                      </button>
                    </form>
                  </td>
                </tr>
              @empty
                <tr>
                  <td colspan="6" class="text-center">Belum ada data.</td>
                </tr>
              @endforelse
            </tbody>
          </table>
        </div>
      </div>

      @if ($data->hasPages())
        <div class="card-footer text-center">
          {{ $data->links('vendor.pagination.bootstrap-4') }}
        </div>
      @endif
    </div>
  </div>
</section>
@endsection
