@extends('admin.layouts.app')

@section('title', 'Tambah Siswa')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Tambah Data Siswa</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('admin.siswa.index') }}">Data siswa</a></div>
      <div class="breadcrumb-item active">Tambah</div>
    </div>
  </div>

  <div class="section-body">

    {{-- Notifikasi sukses --}}
    @if (session('success'))
      <div class="alert alert-success alert-dismissible fade show" role="alert">
        {{ session('success') }}
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
    @endif

    {{-- Notifikasi error --}}
    @if ($errors->any())
      <div class="alert alert-danger alert-dismissible fade show" role="alert">
        <ul class="mb-0">
          @foreach ($errors->all() as $error)
            <li>{{ $error }}</li>
          @endforeach
        </ul>
        <button type="button" class="close" data-dismiss="alert" aria-label="Close">
          <span aria-hidden="true">&times;</span>
        </button>
      </div>
    @endif

    <div class="card" style="max-width: 700px;">
      <div class="card-header">
        <h4>Form Siswa Baru</h4>
      </div>
      <div class="card-body">
        <form action="{{ route('admin.siswa.store') }}" method="POST">
          @csrf

          <div class="form-group">
            <label for="kelas_id">Kelas</label>
            <select name="kelas_id" id="kelas_id" class="form-control" required>
              <option value="">-- Pilih Kelas --</option>
              @foreach ($kelasList as $kelas)
                <option value="{{ $kelas->id }}"
                  {{ old('kelas_id', request('kelas_id')) == $kelas->id ? 'selected' : '' }}>
                  {{ $kelas->nama_kelas }} (Tingkat {{ $kelas->tingkat }})
                </option>
              @endforeach
            </select>
          </div>

          <div class="form-group">
            <label for="tahun_ajaran_id">Tahun Ajaran</label>
            <select name="tahun_ajaran_id" id="tahun_ajaran_id" class="form-control" required>
              <option value="">-- Pilih Tahun Ajaran --</option>
              @foreach ($tahunAjaranList as $ta)
                <option value="{{ $ta->id }}"
                  {{ old('tahun_ajaran_id') == $ta->id ? 'selected' : '' }}>
                  {{ $ta->tahun }}{{ $ta->semester }}
                </option>
              @endforeach
            </select>
          </div>

          <div class="form-group">
            <label for="nisn">NISN</label>
            <input type="text" name="nisn" id="nisn" class="form-control" required value="{{ old('nisn') }}">
          </div>

          <div class="form-group">
            <label for="nama">Nama Lengkap</label>
            <input type="text" name="nama" id="nama" class="form-control" required value="{{ old('nama') }}">
          </div>

          <div class="form-group">
            <label for="email">Email</label>
            <input type="email" name="email" id="email" class="form-control" required value="{{ old('email') }}">
          </div>

          <div class="form-group">
            <label for="alamat">Alamat</label>
            <textarea name="alamat" id="alamat" class="form-control" rows="2">{{ old('alamat') }}</textarea>
          </div>

          <div class="form-group">
            <label for="jenis_kelamin">Jenis Kelamin</label>
            <select name="jenis_kelamin" id="jenis_kelamin" class="form-control" required>
              <option value="">-- Pilih --</option>
              <option value="L" {{ old('jenis_kelamin') == 'L' ? 'selected' : '' }}>Laki-laki</option>
              <option value="P" {{ old('jenis_kelamin') == 'P' ? 'selected' : '' }}>Perempuan</option>
            </select>
          </div>

          <div class="form-group mb-0">
            <button type="submit" class="btn btn-primary">Simpan</button>
            <a href="{{ route('admin.siswa.index') }}" class="btn btn-secondary">Batal</a>
          </div>

        </form>
      </div>
    </div>
  </div>
</section>
@endsection
