@extends('admin.layouts.app')

@section('title', 'Data Siswa Lulus')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Data Siswa Lulus</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item active">Siswa Lulus</div>
    </div>
  </div>

  @if (session('success'))
    <div class="alert alert-success alert-dismissible show fade">
      <div class="alert-body">
        {{ session('success') }}
        <button class="close" data-dismiss="alert">
          <span>&times;</span>
        </button>
      </div>
    </div>
  @endif

  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Data Siswa yang Sudah Lulus</h4>
      </div>
      <div class="card-body">

        {{-- Filter Tahun Ajaran --}}
        <form method="GET" action="{{ route('admin.siswa.lulus') }}" class="form-inline mb-4">
          <div class="form-group mr-2">
            <label for="tahun_ajaran_id" class="mr-2">Tahun Ajaran</label>
            <select name="tahun_ajaran_id" id="tahun_ajaran_id" class="form-control" onchange="this.form.submit()">
              <option value="">-- Semua Tahun --</option>
              @foreach ($tahunAjaranList as $ta)
                <option value="{{ $ta->id }}" {{ request('tahun_ajaran_id') == $ta->id ? 'selected' : '' }}>
                  {{ $ta->tahun }} {{ $ta->semester }}
                </option>
              @endforeach
            </select>
          </div>
        </form>

        {{-- Tabel Data --}}
        <div class="table-responsive">
          <table class="table table-striped table-md">
            <thead>
              <tr>
                <th>#</th>
                <th>Kelas</th>
                <th>Tingkat</th>
                <th>Tahun Ajaran</th>
                <th>NISN</th>
                <th>Nama</th>
                <th>Jenis Kelamin</th>
                <th>Alamat</th>
                <th>Email</th>
              </tr>
            </thead>
            <tbody>
              @forelse($data as $index => $siswa)
                <tr>
                  <td>{{ $data->firstItem() + $index }}</td>
                  <td>{{ $siswa->kelas->nama_kelas ?? '-' }}</td>
                  <td>{{ $siswa->kelas->tingkat ?? '-' }}</td>
                  <td>{{ $siswa->tahunAjaran->tahun ?? '-' }} {{ $siswa->tahunAjaran->semester ?? '-' }}</td>
                  <td>{{ $siswa->nisn }}</td>
                  <td>{{ $siswa->nama }}</td>
                  <td>{{ $siswa->jenis_kelamin == 'L' ? 'Laki-laki' : 'Perempuan' }}</td>
                  <td>{{ $siswa->alamat ?? '-' }}</td>
                  <td>{{ $siswa->user->email ?? '-' }}</td>
                </tr>
              @empty
                <tr>
                  <td colspan="9" class="text-center">Tidak ada siswa yang lulus.</td>
                </tr>
              @endforelse
            </tbody>
          </table>
        </div>

        {{-- Pagination --}}
        <div class="mt-3">
          {{ $data->links('pagination::bootstrap-4') }}
        </div>

      </div>
    </div>
  </div>
</section>
@endsection
