@extends('admin.layouts.app')

@section('title', 'Data Tahun Ajaran')

@section('breadcrumb')
  <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
  <div class="breadcrumb-item active">Data Tahun Ajaran</div>
@endsection

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Data Tahun Ajaran</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('admin.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item active">Data Tahun Ajaran</div>
    </div>
    <div class="section-header-button">
      <a href="{{ route('admin.tahun_ajaran.create') }}" class="btn btn-primary">+ Tambah Tahun Ajaran</a>
    </div>
  </div>

  {{-- Notifikasi sukses --}}
  @if (session('success'))
    <div class="alert alert-success alert-dismissible show fade">
      <div class="alert-body">
        {{ session('success') }}
        <button class="close" data-dismiss="alert">
          <span>&times;</span>
        </button>
      </div>
    </div>
  @endif

  {{-- Notifikasi error jika ada --}}
  @if (session('error'))
    <div class="alert alert-danger alert-dismissible show fade">
      <div class="alert-body">
        {{ session('error') }}
        <button class="close" data-dismiss="alert">
          <span>&times;</span>
        </button>
      </div>
    </div>
  @endif

  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Daftar Tahun Ajaran</h4>
      </div>
      <div class="card-body p-0">
        <div class="table-responsive">
          <table class="table table-striped table-md">
            <thead>
              <tr>
                <th>#</th>
                <th>Tahun</th>
                <th>Semester</th>
                <th>Status</th>
                <th>Aksi</th>
              </tr>
            </thead>
            <tbody>
              @forelse ($tahunAjarans as $tahun)
              <tr>
                <td>{{ $loop->iteration }}</td>
                <td>{{ $tahun->tahun }}</td>
                <td>{{ ucfirst($tahun->semester) }}</td>
                <td>
                  @if ($tahun->status === 'aktif')
                    <span class="badge badge-success">Aktif</span>
                  @elseif ($tahun->status === 'tidak aktif')
                    <span class="badge badge-secondary">Tidak Aktif</span>
                  @elseif ($tahun->status === 'lulus')
                    <span class="badge badge-info">Lulus</span>
                  @else
                    <span class="badge badge-light">{{ $tahun->status }}</span>
                  @endif
                </td>
                <td>
                  <a href="{{ route('admin.tahun_ajaran.edit', $tahun->id) }}" class="btn btn-warning btn-sm"><i class="fas fa-edit"></i></a>
                  <form action="{{ route('admin.tahun_ajaran.destroy', $tahun->id) }}" method="POST" class="d-inline" onsubmit="return confirm('Yakin ingin menghapus?')">
                    @csrf
                    @method('DELETE')
                    <button class="btn btn-danger btn-sm"><i class="fas fa-trash"></i></button>
                  </form>
                </td>
              </tr>
              @empty
              <tr>
                <td colspan="5" class="text-center">Belum ada data tahun ajaran.</td>
              </tr>
              @endforelse
            </tbody>
          </table>
        </div>
      </div>
    </div>
  </div>
</section>
@endsection
