@extends('guru.layouts.app')

@section('page_title', 'Daftar Materi')

@section('breadcrumb')
  <div class="breadcrumb-item"><a href="{{ route('guru.dashboard') }}">Dashboard</a></div>
  <div class="breadcrumb-item"><a href="{{ route('guru.pelajaran.index') }}">Pelajaran</a></div>
  <div class="breadcrumb-item active">Materi</div>
@endsection

@section('content')
<section class="section">
  <div class="section-header">
    <h1>@yield('page_title')</h1>
    <div class="section-header-breadcrumb">
      @yield('breadcrumb')
    </div>
  </div>

  <div class="section-body">
    <p class="section-lead">@yield('page_description')</p>

    <div class="mb-4">
      <a href="{{ route('guru.materi.create', ['mapel_id' => $mapel->id]) }}" class="btn btn-primary">
        <i class="fas fa-plus"></i> Tambah Materi
      </a>
    </div>

    <div class="card">
      <div class="card-header">
        <h4>Daftar Materi</h4>
        <div class="card-header-form">
          <form method="GET" action="{{ route('guru.materi.index') }}">
            <div class="input-group">
              <input type="text" name="q" class="form-control" placeholder="Cari materi..." value="{{ request('q') }}">
              <div class="input-group-append">
                <button class="btn btn-primary"><i class="fas fa-search"></i></button>
              </div>
            </div>
          </form>
        </div>
      </div>

      <div class="card-body p-0">
        <div class="table-responsive">
          <table class="table table-striped mb-0">
            <thead>
              <tr>
                <th class="text-center"><i class="fas fa-th"></i></th>
                <th>Judul</th>
                <th>Isi</th>
                <th>Type</th>
                <th>Kelas & Tanggal Terbit</th>
                <th>Aksi</th>
              </tr>
            </thead>
            <tbody>
              @forelse ($materi as $item)
                {{-- Materi Utama --}}
                <tr>
                  <td class="text-center"><i class="fas fa-book"></i></td>
                  <td>
                    <a href="{{ route('guru.materi.editIsi', $item->id) }}" class="font-weight-bold" title="Edit Isi">
                      {{ $item->judul }}
                    </a>
                  </td>
                  <td>
                    <a href="{{ route('guru.materi.preview', $item->id) }}" target="_blank" title="Preview">
                      {{ Str::limit(strip_tags($item->isi), 50) }}
                    </a>
                  </td>
                  <td><span class="badge badge-success">Parent</span></td>
                  <td>
                    @foreach($item->kelas as $kelas)
                      <div>
                        <strong>{{ $kelas->nama_kelas }}{{ $kelas->tingkat }}</strong><br>
                        <small>Tanggal Terbit: {{ $kelas->pivot->tanggal_terbit ?? '-' }}</small>
                      </div>
                    @endforeach
                  </td>
                  <td>
                    <a href="{{ route('guru.materi.edit', $item->id) }}" class="btn btn-sm btn-outline-primary" title="Edit">
                      <i class="fas fa-edit"></i>
                    </a>
                    <a href="{{ route('guru.materi.create', ['parent_id' => $item->id]) }}" class="btn btn-sm btn-outline-success" title="Tambah Submateri">
                      <i class="fas fa-plus"></i>
                    </a>
                    <form action="{{ route('guru.materi.destroy', $item->id) }}" method="POST" class="d-inline" onsubmit="return confirm('Yakin ingin menghapus materi ini?')">
                      @csrf @method('DELETE')
                      <button class="btn btn-sm btn-outline-danger" title="Hapus">
                        <i class="fas fa-trash"></i>
                      </button>
                    </form>
                  </td>
                </tr>

                {{-- Submateri --}}
                @foreach ($item->children as $child)
                  <tr>
                    <td class="text-center"><i class="fas fa-level-up-alt text-muted"></i></td>
                    <td>
                      <a href="{{ route('guru.materi.editIsi', $child->id) }}" title="Edit Isi">
                        &mdash; {{ $child->judul }}
                      </a>
                    </td>
                    <td>
                      <a href="{{ route('guru.materi.preview', $child->id) }}" target="_blank" title="Preview">
                        {{ Str::limit(strip_tags($child->isi), 50) }}
                      </a>
                    </td>
                    <td><span class="badge badge-info">Sub</span></td>
                    <td>
                      @foreach($child->kelas as $kelas)
                        <div>
                          <strong>{{ $kelas->nama_kelas }}{{ $kelas->tingkat }}</strong><br>
                          <small>Tanggal Terbit: {{ $kelas->pivot->tanggal_terbit ?? '-' }}</small>
                        </div>
                      @endforeach
                    </td>
                    <td>
                      <a href="{{ route('guru.materi.edit', $child->id) }}" class="btn btn-sm btn-outline-primary" title="Edit">
                        <i class="fas fa-edit"></i>
                      </a>
                      <form action="{{ route('guru.materi.destroy', $child->id) }}" method="POST" class="d-inline" onsubmit="return confirm('Yakin ingin menghapus submateri ini?')">
                        @csrf @method('DELETE')
                        <button class="btn btn-sm btn-outline-danger" title="Hapus">
                          <i class="fas fa-trash"></i>
                        </button>
                      </form>
                    </td>
                  </tr>
                @endforeach

              @empty
                <tr>
                  <td colspan="6" class="text-center text-muted">Belum ada materi.</td>
                </tr>
              @endforelse
            </tbody>
          </table>
        </div>
      </div>
    </div>
  </div>
</section>
@endsection
