@extends('guru.layouts.app')

@section('title', 'Daftar Soal Pilihan Ganda')

@section('content')
<section class="section">
  <div class="section-header">
    <h1>Daftar Soal Pilihan Ganda</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item">
        <a href="{{ route('guru.dashboard') }}">Dashboard</a>
      </div>
      <div class="breadcrumb-item">
        <a href="{{ route('guru.ujian.index') }}">Daftar Ujian</a>
      </div>
      <div class="breadcrumb-item active">Soal PG</div>
    </div>
  </div>

  <div class="section-body">

    @if(session('success'))
      <div class="alert alert-success alert-dismissible show fade">
        {{ session('success') }}
        <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
      </div>
    @endif

    <div class="card">
      <div class="card-body">

        <p><strong>Ujian:</strong> {{ $ujian->judul }}</p>
        <p><strong>Waktu:</strong> {{ $ujian->waktu }} Menit</p>

        <div class="d-flex justify-content-end mb-3 gap-2 align-items-center flex-wrap">

          <a href="{{ route('guru.ujian.soal_pg.create', $ujian->id) }}" class="btn btn-primary">
            + Soal PG
          </a>

          {{-- Form import dengan tombol icon --}}
          <form id="importForm" action="{{ route('guru.ujian.soal_pg.import', $ujian->id) }}" method="POST" enctype="multipart/form-data" style="display: none;">
            @csrf
            <input type="file" name="file" id="importFile" accept=".xlsx,.xls" />
          </form>

          {{-- Tombol icon untuk trigger input file --}}
          <button id="importButton" class="btn btn-primary" title="Import Soal Excel">
            <i class="fas fa-file-excel"></i> <!-- FontAwesome icon, pastikan sudah ada -->
          </button>

          <a href="{{ route('guru.ujian.soal_pg.export', $ujian->id) }}" class="btn btn-success" title="Export Soal ke Excel">
            <i class="fas fa-file-export"></i> Export
          </a>

        </div>

        <table class="table table-bordered table-striped">
          <thead>
            <tr>
              <th>No</th>
              <th>Pertanyaan</th>
              <th>Opsi</th>
              <th>Jawaban</th>
              <th>Edit</th>
              <th>Hapus</th>
            </tr>
          </thead>
          <tbody>
            @forelse ($soalPilgan as $soal)
              <tr>
                <td>{{ $loop->iteration }}</td>
                <td>{{ $soal->pertanyaan }}</td>
                <td>
                  <ul class="mb-0 ps-3">
                    <li>A: {{ $soal->opsi_a }}</li>
                    <li>B: {{ $soal->opsi_b }}</li>
                    <li>C: {{ $soal->opsi_c }}</li>
                    <li>D: {{ $soal->opsi_d }}</li>
                  </ul>
                </td>
                <td>{{ strtoupper($soal->jawaban_benar) }}</td>
                <td>
                  <a href="{{ route('guru.ujian.soal_pg.edit', ['ujian' => $soal->ujian_id, 'soal' => $soal->id]) }}" class="btn btn-warning btn-sm" title="Edit Soal">
                    ✏️
                  </a>
                </td>
                <td>
                  <form action="{{ route('guru.ujian.soal_pg.destroy', ['ujian' => $soal->ujian_id, 'soal' => $soal->id]) }}" method="POST" onsubmit="return confirm('Hapus soal ini?')">
                    @csrf
                    @method('DELETE')
                    <button class="btn btn-danger btn-sm" title="Hapus Soal">🗑️</button>
                  </form>
                </td>
              </tr>
            @empty
              <tr>
                <td colspan="6" class="text-center">Belum ada soal PG.</td>
              </tr>
            @endforelse
          </tbody>
        </table>

      </div>
    </div>
  </div>
</section>

{{-- Script untuk handle import file upload --}}
@push('scripts')
<script>
  document.getElementById('importButton').addEventListener('click', function() {
    document.getElementById('importFile').click();
  });

  document.getElementById('importFile').addEventListener('change', function() {
    if(this.files.length > 0){
      document.getElementById('importForm').submit();
    }
  });
</script>
@endpush

@endsection
