@extends('guru.layouts.app')

@section('content')
<section class="section">
    <div class="section-header">
    <h1>Tambah tugas</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('guru.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('guru.tugas.index') }}">Tugas</a></div>
    </div>
  </div>


  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Form Tambah Tugas</h4>
      </div>
      <div class="card-body">

        @if ($errors->any())
          <div class="alert alert-danger">
            <div class="alert-title"><i class="fas fa-exclamation-circle"></i> Kesalahan Input</div>
            <ul class="mb-0">
              @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
              @endforeach
            </ul>
          </div>
        @endif

        <form action="{{ route('guru.tugas.store') }}" method="POST" enctype="multipart/form-data">
          @csrf

          {{-- Pilih Materi --}}
          <div class="form-group">
            <label for="materi_id">Pilih Materi</label>
            <select name="materi_id" id="materi_id" class="form-control select2" required>
              <option value="">-- Pilih Materi --</option>
              @foreach ($materiList as $materi)
                <option value="{{ $materi->id }}" {{ old('materi_id') == $materi->id ? 'selected' : '' }}>
                  {{ $materi->judul }}
                </option>
              @endforeach
            </select>
          </div>

          {{-- Judul Tugas --}}
          <div class="form-group">
            <label for="judul">Judul Tugas</label>
            <input type="text" name="judul" id="judul" class="form-control" value="{{ old('judul') }}" required>
          </div>

          {{-- Deskripsi --}}
          <div class="form-group">
            <label for="deskripsi">Deskripsi Tugas</label>
            <textarea name="deskripsi" class="form-control summernote" rows="5">{{ old('deskripsi') }}</textarea>
          </div>

          {{-- Upload File --}}
          <div class="form-group">
            <label for="file">Upload File</label>
            <input type="file" name="file" class="form-control-file">
            <small class="form-text text-muted">
              Maks. 20MB. Format yang didukung: pdf, docx, jpg, png, mp4, mov.
            </small>
          </div>

          {{-- Pilih Kelas dan Deadline --}}
          <div class="form-group">
            <label>Pilih Kelas dan Deadline</label>
            @foreach($kelasList as $kelas)
              <div class="form-check mb-3 border p-3 rounded">
                <div class="custom-control custom-checkbox">
                  <input
                    type="checkbox"
                    class="custom-control-input"
                    id="kelas_{{ $kelas->id }}"
                    name="kelas_ids[]"
                    value="{{ $kelas->id }}"
                    {{ in_array($kelas->id, old('kelas_ids', [])) ? 'checked' : '' }}
                  >
                  <label class="custom-control-label font-weight-bold" for="kelas_{{ $kelas->id }}">
                    {{ $kelas->nama_kelas }}{{ $kelas->tingkat }}
                  </label>
                </div>
                <input
                  type="datetime-local"
                  name="deadlines[{{ $kelas->id }}]"
                  class="form-control mt-2"
                  value="{{ old('deadlines.' . $kelas->id) }}"
                >
              </div>
            @endforeach
          </div>

          {{-- Tombol Simpan --}}
          <div class="form-group text-right mt-4">
            <button type="submit" class="btn btn-primary btn-lg">
              <i class="fas fa-save"></i> Simpan Tugas
            </button>
          </div>
        </form>

      </div>
    </div>
  </div>
</section>
@endsection
