@extends('guru.layouts.app')

@section('content')
<section class="section">
   <div class="section-header">
    <h1>Edi tugas</h1>
    <div class="section-header-breadcrumb">
      <div class="breadcrumb-item"><a href="{{ route('guru.dashboard') }}">Dashboard</a></div>
      <div class="breadcrumb-item"><a href="{{ route('guru.tugas.index') }}">Tugas</a></div>
    </div>
  </div>

  <div class="section-body">
    <div class="card">
      <div class="card-header">
        <h4>Form Edit Tugas</h4>
      </div>

      <div class="card-body">
        @if ($errors->any())
          <div class="alert alert-danger">
            <ul class="mb-0">
              @foreach ($errors->all() as $error)
                <li>{{ $error }}</li>
              @endforeach
            </ul>
          </div>
        @endif

        <form action="{{ route('guru.tugas.update', $tugas->id) }}" method="POST" enctype="multipart/form-data">
          @csrf
          @method('PUT')

          {{-- Pilih Materi --}}
          <div class="form-group">
            <label for="materi_id">Pilih Materi</label>
            <select name="materi_id" id="materi_id" class="form-control" required>
              <option value="">-- Pilih Materi --</option>
              @foreach ($materiList as $materi)
                <option value="{{ $materi->id }}" {{ (old('materi_id', $tugas->materi_id) == $materi->id) ? 'selected' : '' }}>
                  {{ $materi->judul }}
                </option>
              @endforeach
            </select>
          </div>

          {{-- Judul Tugas --}}
          <div class="form-group">
            <label for="judul">Judul Tugas</label>
            <input
              type="text"
              name="judul"
              id="judul"
              class="form-control"
              value="{{ old('judul', $tugas->judul) }}"
              required
            >
          </div>

          {{-- Deskripsi --}}
          <div class="form-group">
            <label for="deskripsi">Deskripsi Tugas</label>
            <textarea
              name="deskripsi"
              class="form-control summernote"
              rows="5"
            >{{ old('deskripsi', $tugas->deskripsi) }}</textarea>
          </div>

          {{-- Upload File --}}
          <div class="form-group">
            <label for="file">Upload File (PDF, Gambar, Video)</label>
            <input type="file" name="file" class="form-control-file">
            @if($tugas->file)
              <small class="form-text text-muted">
                File saat ini: <a href="{{ asset('storage/' . $tugas->file) }}" target="_blank">{{ basename($tugas->file) }}</a>
              </small>
            @endif
            <small class="form-text text-muted">
              File maksimal 20MB. Format: pdf, docx, jpg, png, mp4, mov.
            </small>
          </div>

          {{-- Pilih Kelas dan Deadline --}}
          <div class="form-group">
            <label>Pilih Kelas dan Deadline</label>
            @foreach($kelasList as $kelas)
              @php
                $kelasTugas = $tugas->kelas->firstWhere('id', $kelas->id);
              @endphp
              <div class="form-check mb-3 border p-3 rounded">
                <div class="custom-control custom-checkbox">
                  <input
                    type="checkbox"
                    class="custom-control-input"
                    id="kelas_{{ $kelas->id }}"
                    name="kelas_ids[]"
                    value="{{ $kelas->id }}"
                    {{ (is_array(old('kelas_ids', $tugas->kelas->pluck('id')->toArray())) && in_array($kelas->id, old('kelas_ids', $tugas->kelas->pluck('id')->toArray()))) ? 'checked' : '' }}
                  >
                  <label class="custom-control-label font-weight-bold" for="kelas_{{ $kelas->id }}">
                    {{ $kelas->nama_kelas }}{{ $kelas->tingkat }}
                  </label>
                </div>
                <input
                  type="datetime-local"
                  name="deadlines[{{ $kelas->id }}]"
                  class="form-control mt-2"
                  value="{{ old('deadlines.' . $kelas->id, $kelasTugas && $kelasTugas->pivot->deadline ? \Carbon\Carbon::parse($kelasTugas->pivot->deadline)->format('Y-m-d\TH:i') : '') }}"
                >
              </div>
            @endforeach
          </div>

          {{-- Tombol Simpan --}}
          <div class="form-group text-right">
            <a href="{{ route('guru.tugas.index') }}" class="btn btn-secondary mr-2">
              <i class="fas fa-times"></i> Batal
            </a>
            <button type="submit" class="btn btn-primary">
              <i class="fas fa-save"></i> Update Tugas
            </button>
          </div>
        </form>
      </div>
    </div>
  </div>
</section>
@endsection
